---
title: Integration with other services
---

stellar-core is at the bottom of the Stellar stack, many other services can be
 built on top of it.

 Example of such services include Horizon, a modular service to assist with
 submitting transactions to the network as well as exposing a data model to
 query ledger history.

# Integration points
## Data consumers
Many types of services can be built based on the data generated by stellar-core.

stellar-core generates two types of data that can be queried by applications.

Unless otherwise noted, data stored is `validated`, ie data is only persisted
after consensus is reached on the network.

An overview of how the data flows within stellar-core is [this data flow presentation](software/core-data-flow.pdf)

### SQL tables
This includes near real time version of the changes that occured in the network
as well as the current state of the ledger.
Applications can safely perform READ ONLY transactions on the data located there.
The schema is described in [`db-schema.md`](db-schema.md)

**Important**: when consuming data from SQL, be sure that your service is
properly registered by updating its cursor so that stellar-core can safely
garbage collect data no longer needed.
By default stellar-core only keeps track of its internal state and will
 therefore delete data it does not need anymore.
See `setcursor` in [`software/commands.md#http-commands`](software/commands.md#http-commands)

Advantages of consuming SQL tables for a dependent service:
 * data is available as soon as the network closes a ledger.
 * additional meta data not available in history is produced by stellar-core.
 * allows to efficiently perform filtering (audit certain users or
   transaction types).

### History archives
Services can also process the flat files uploaded periodically to the
archive stores.
Advantages of building on top of history archives over SQL tables include:
 * allows to build an aggregate view going back to arbitrary points in time.
 * does not depend on running stellar-core (can be built as a pure client
   application or within a foreign stack). The only thing needed is the XDR
   deserialization code and code to fetch data from the archive.

See [`history.md`](history.md) for more detail.

### Stellar core database

## API to stellar-core
  stellar-core exposes a simple HTTP based API for performing various
  types of operations on stellar-core itself or on entities in the network
  (such as submitting transactions).
  See [`software/commands.md`](software/commands.md) for more information.
